import 'package:flutter/foundation.dart';
import 'package:wordguessing/models/word.dart';

class Data extends ChangeNotifier {
  // Language
  String _lang = '';

  // randomization
  Word? _word;
  List<Word> _otherWords = [];
  List<Word> _images = [];
  final int _recentWordsCount = 20;
  List<String> _recentWordsKeys = [];

  // game data
  int _questionsCount = 0;
  int _goodAnswers = 0;
  int _wrongAnswers = 0;

  String get lang => _lang;

  set updateLang(String value) {
    _lang = value;
    notifyListeners();
  }

  Word? get word => _word;

  set updateWord(Word? newWord) {
    _word = newWord;
    if ((newWord != null) && (newWord.key != '')) {
      _recentWordsKeys.insert(0, newWord.key);
      _recentWordsKeys = _recentWordsKeys.take(_recentWordsCount).toList();
    }
    notifyListeners();
  }

  bool isRecentlyPicked(String word) {
    return _recentWordsKeys.contains(word);
  }

  List get otherWords => _otherWords;

  set updateOtherWords(List<Word> words) {
    _otherWords = words;
    notifyListeners();
  }

  List<Word> get images => _images;

  set updateImages(List<Word> images) {
    _images = images;
    notifyListeners();
  }

  void resetGame() {
    _word = null;
    _otherWords = [];
    _images = [];
    _questionsCount = 0;
    _goodAnswers = 0;
    _wrongAnswers = 0;
    notifyListeners();
  }

  int get questionsCount => _questionsCount;

  set updateQuestionsCount(int value) {
    _questionsCount = value;
    notifyListeners();
  }

  int get goodAnswers => _goodAnswers;

  set updateGoodAnswers(int value) {
    _goodAnswers = value;
    notifyListeners();
  }

  int get wrongAnswers => _wrongAnswers;

  set updateWrongAnswers(int value) {
    _wrongAnswers = value;
    notifyListeners();
  }
}
