import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../provider/data.dart';

class Home extends StatelessWidget {
  static const String id = 'home';

  Future<void> resetGame(Data myProvider) async {
    myProvider.updateLang = '';
    myProvider.updateQuestionsCount = 0;
    myProvider.updateGoodAnswers = 0;
    myProvider.updateWrongAnswers = 0;
    myProvider.updateWord = null;
    myProvider.updateOtherWords = [];
    myProvider.updateImages = [];
  }

  @override
  Widget build(BuildContext context) {
    Data myProvider = Provider.of<Data>(context);

    Container _buildMenuItemContainer(String code, Color color) {
      double imageSize = 150;

      String imageAsset = 'assets/menu/' + code + '.png';

      return Container(
        margin: EdgeInsets.all(2),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8),
          border: Border.all(
            color: color,
            width: 12,
          ),
        ),
        child: GestureDetector(
          child: Image(
            image: AssetImage(imageAsset),
            width: imageSize,
            height: imageSize,
            fit: BoxFit.fill,
          ),
          onTap: () {
            resetGame(myProvider);
            Navigator.pushNamed(
              context,
              '/' + code,
            );
          },
        ),
      );
    }

    return Scaffold(
      backgroundColor: Colors.blue,
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            _buildMenuItemContainer('game-pick-word', Colors.pink),
            _buildMenuItemContainer('game-pick-image', Colors.yellow),
          ],
        ),
      ),
    );
  }
}
